'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const highlightWordsCore = require('highlight-words-core');
const vue = require('vue');

function VueHighlighterImpl(props, context) {
  const chunks = highlightWordsCore.findAll({
    autoEscape: props.autoEscape,
    caseSensitive: props.caseSensitive,
    findChunks: props.findChunks,
    sanitize: props.sanitize,
    searchWords: props.searchWords,
    textToHighlight: props.textToHighlight
  });
  const children = getTextChildren(props, chunks);
  const slots = context.slots;
  if (slots.default) {
    return slots.default && slots.default(children);
  }
  return vue.h(
    "span",
    { ...context.attrs },
    children.map(({ chunk, text, attrs }) => {
      if (!chunk.highlight) {
        return text;
      }
      const eventHandlers = {};
      if (props.onWordClick) {
        eventHandlers.onClick = () => props.onWordClick?.({ chunk, text, attrs });
      }
      if (props.onWordHover) {
        eventHandlers.onMouseover = () => props.onWordHover?.({ chunk, text, attrs });
      }
      return vue.h("mark", { ...attrs, ...eventHandlers }, [text]);
    })
  );
}
const EMPTY_STYLE = {};
function getTextChildren(props, chunks) {
  let highlightCount = -1;
  const {
    textToHighlight,
    highlightClassName,
    highlightStyle = EMPTY_STYLE,
    activeIndex,
    activeClassName,
    activeStyle = EMPTY_STYLE
  } = props;
  return chunks.map((chunk, index) => {
    const text = textToHighlight.slice(chunk.start, chunk.end);
    if (!chunk.highlight) {
      return { chunk, text };
    }
    highlightCount++;
    const isActive = highlightCount === +(activeIndex || -1);
    const attrs = {
      class: `${highlightClassName} ${isActive ? activeClassName : ""}`,
      key: index,
      style: isActive && activeStyle != null ? { ...highlightStyle, ...activeStyle } : highlightStyle,
      highlightIndex: highlightCount
    };
    return { chunk, text, attrs };
  });
}
VueHighlighterImpl.props = {
  activeClassName: String,
  activeIndex: Number,
  activeStyle: Object,
  autoEscape: Boolean,
  caseSensitive: {
    type: Boolean,
    default: false
  },
  findChunks: Function,
  custom: {
    type: Boolean,
    default: false
  },
  highlightClassName: String,
  highlightStyle: Object,
  onWordClick: Function,
  onWordHover: Function,
  sanitize: Function,
  searchWords: {
    type: Array,
    // string[]
    validator(value) {
      return value.every((word) => typeof word === "string");
    },
    required: true
  },
  textToHighlight: {
    type: String,
    required: true
  }
};
const VueHighlighter = VueHighlighterImpl;

function install(app, options = { name: "" }) {
  app.component(options.name || "VueHighlighter", VueHighlighter);
}

exports.VueHighlighter = VueHighlighter;
exports.default = VueHighlighter;
exports.install = install;
